@@ -5,6 +5,6 @@ export starting="${BASH_SOURCE[0]}"; debug.sh starting
 unset VIRTUAL_ENV PYTHONHOME
 deactivate > /dev/null 2>&1
 
-project-upgrade.sh "$( basename "${PROJECT_BASHRC}" )" || exit 1
+project-upgrade.sh "$( basename "${BASHRC}" )" || exit 1
 
 unset starting
