@@ -12,18 +12,18 @@ case "${1}" in
   patch) bump="${1}" ;;
 esac; shift
 
-test -n "${PROJECT_BASHRC}" || { error.sh "PROJECT_BASHRC" "empty"; exit 1; }
-cd "${PROJECT_BASHRC}" > /dev/null 2>&1 || { error.sh "${PROJECT_BASHRC}" "does not exists"; exit 1; }
+test -n "${BASHRC}" || { error.sh " BASHRC" "empty"; exit 1; }
+cd "${BASHRC}" > /dev/null 2>&1 || { error.sh "${BASHRC}" "does not exists"; exit 1; }
 
 unset VIRTUAL_ENV PYTHONHOME
 deactivate > /dev/null 2>&1
 
-project-upload.sh "${PROJECT_BASHRC}" "${bump}" "${GITHUB_USERNAME}" || exit 1
+project-upload.sh "${BASHRC}" "${bump}" "${GITHUB_USERNAME}" || exit 1
 
 unset VIRTUAL_ENV PYTHONHOME
 deactivate > /dev/null 2>&1
 
-project-upgrade.sh "$( basename "${PROJECT_BASHRC}" )" || exit 1
+project-upgrade.sh "$( basename "${BASHRC}" )" || exit 1
 
 cd - > /dev/null || exit 1
 
